package com.yushu.system.mapper;

import com.yushu.system.domain.AiProvider;
import java.util.List;

/**
 * AI厂商Mapper接口
 * 
 * @author yushu
 * @date 2024-11-06
 */
public interface AiProviderMapper {
    /**
     * 查询AI厂商
     * 
     * @param providerId AI厂商主键
     * @return AI厂商
     */
    public AiProvider selectAiProviderByProviderId(Long providerId);

    /**
     * 查询AI厂商列表
     * 
     * @param aiProvider AI厂商
     * @return AI厂商集合
     */
    public List<AiProvider> selectAiProviderList(AiProvider aiProvider);

    /**
     * 新增AI厂商
     * 
     * @param aiProvider AI厂商
     * @return 结果
     */
    public int insertAiProvider(AiProvider aiProvider);

    /**
     * 修改AI厂商
     * 
     * @param aiProvider AI厂商
     * @return 结果
     */
    public int updateAiProvider(AiProvider aiProvider);

    /**
     * 删除AI厂商
     * 
     * @param providerId AI厂商主键
     * @return 结果
     */
    public int deleteAiProviderByProviderId(Long providerId);

    /**
     * 批量删除AI厂商
     * 
     * @param providerIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAiProviderByProviderIds(Long[] providerIds);
}

